import random
import logging
from typing import List

import click
import requests
from bs4 import BeautifulSoup

from byb.core import Bot, PostContent
from byb.bots.core import platform_opt
from byb.utils import browser, image

log = logging.getLogger(__name__)

NAME = "geocities-archive-crawler"
BASE_URL = "http://www.oocities.org/"
DEFAULT_SUB_NEIGHBORHOOD = "Rainforest/Andes"
DEFAULT_MESSAGE = "went surfing last night: "

# Source: geocities.com/geocities-archive
# List of Geocities Neighborhoods and Subneighborhoods
SUB_NEIGHBORHOODS = [
    "area51/Alien",
    "area51/Atlantis",
    "area51/Aurora",
    "area51/Capsule",
    "area51/Cavern",
    "area51/Chamber",
    "area51/Comet",
    "area51/Corridor",
    "area51/Crater",
    "area51/Dimension",
    "area51/Dreamworld",
    "area51/Dunes",
    "area51/Dungeon",
    "area51/Hole",
    "area51/Hollow",
    "area51/Jupiter",
    "area51/Keep",
    "area51/Labyrinth",
    "area51/Lair",
    "area51/Matrix",
    "area51/Meteor",
    "area51/Nebula",
    "area51/Neptune",
    "area51/Nova",
    "area51/Omega",
    "area51/Orion",
    "area51/Portal",
    "area51/Quadrant",
    "area51/Quark",
    "area51/Quasar",
    "area51/Rampart",
    "area51/Realm",
    "area51/Saturn",
    "area51/Shadowlands",
    "area51/Shire",
    "area51/Shuttle",
    "area51/Stargate",
    "area51/Starship",
    "area51/Station",
    "area51/Underworld",
    "area51/Vault",
    "area51/Zone",
    "athens/Academy",
    "athens/Acropolis",
    "athens/Aegean",
    "athens/Agora",
    "athens/Atlantis",
    "athens/Atrium",
    "athens/Bridge",
    "athens/Column",
    "athens/Crete",
    "athens/Cyprus",
    "athens/Delphi",
    "athens/Forum",
    "athens/Ithaca",
    "athens/Library",
    "athens/Marathon",
    "athens/Olympus",
    "athens/Oracle",
    "athens/Pantheon",
    "athens/Parthenon",
    "athens/Rhodes",
    "athens/Sparta",
    "athens/Stage",
    "athens/Styx",
    "athens/Thebes",
    "athens/Troy",
    "Augusta/Fairway",
    "Augusta/Green",
    "Augusta/Links",
    "baja/Canyon",
    "baja/Cliffs",
    "baja/Desert",
    "baja/Dunes",
    "baja/Mesa",
    "baja/Outback",
    "baja/Ravine",
    "baja/Trails",
    "Bourbonstreet/Bayou",
    "Bourbonstreet/Canal",
    "Bourbonstreet/Delta",
    "Bourbonstreet/Inn",
    "Bourbonstreet/Quarter",
    "Bourbonstreet/Square",
    "Capecanaveral/Campus",
    "Capecanaveral/Cockpit",
    "Capecanaveral/Galaxy",
    "Capecanaveral/Hall",
    "Capecanaveral/Hangar",
    "Capecanaveral/Lab",
    "Capecanaveral/Launchpad",
    "Capecanaveral/Orbit",
    "Capecanaveral/Runway",
    "Capecanaveral/Shuttle",
    "Capecanaveral/Station",
    "Capitolhill/Congress",
    "Capitolhill/Embassy",
    "Capitolhill/Lobby",
    "Capitolhill/Parliament",
    "Capitolhill/Rotunda",
    "Capitolhill/Senate",
    "Collegepark/Bookstore",
    "Collegepark/Campus",
    "Collegepark/Center",
    "Collegepark/Classroom",
    "Collegepark/Club",
    "Collegepark/Den",
    "Collegepark/Dorm",
    "Collegepark/Field",
    "Collegepark/Grounds",
    "Collegepark/Gym",
    "Collegepark/Hall",
    "Collegepark/Housing",
    "Collegepark/Lab",
    "Collegepark/Library",
    "Collegepark/Locker",
    "Collegepark/Lounge",
    "Collegepark/Plaza",
    "Collegepark/Pool",
    "Collegepark/Quad",
    "Collegepark/Residence",
    "Collegepark/Square",
    "Collegepark/Stadium",
    "Collegepark/Theater",
    "Collegepark/Union",
    "Colosseum/Arena",
    "Colosseum/Base",
    "Colosseum/Bench",
    "Colosseum/Bleachers",
    "Colosseum/Court",
    "Colosseum/Dome",
    "Colosseum/Dugout",
    "Colosseum/Field",
    "Colosseum/Goal",
    "Colosseum/Gym",
    "Colosseum/Hoop",
    "Colosseum/Lane",
    "Colosseum/Lodge",
    "Colosseum/Loge",
    "Colosseum/Midfield",
    "Colosseum/Mound",
    "Colosseum/Park",
    "Colosseum/Pennant",
    "Colosseum/Pool",
    "Colosseum/Pressbox",
    "Colosseum/Ring",
    "Colosseum/Rink",
    "Colosseum/Sideline",
    "Colosseum/Slope",
    "Colosseum/Stadium",
    "Colosseum/Stands",
    "Colosseum/Track",
    "Colosseum/Turf",
    "Enchantedforest/Arbor",
    "Enchantedforest/Cottage",
    "Enchantedforest/Cove",
    "Enchantedforest/Creek",
    "Enchantedforest/Dell",
    "Enchantedforest/Fountain",
    "Enchantedforest/Garden",
    "Enchantedforest/Glade",
    "Enchantedforest/Kingdom",
    "Enchantedforest/Meadow",
    "Enchantedforest/Mountain",
    "Enchantedforest/Palace",
    "Enchantedforest/Pond",
    "Enchantedforest/Tower",
    "eureka/Account",
    "eureka/Boardroom",
    "eureka/Business",
    "eureka/Company",
    "eureka/Concourse",
    "eureka/Consultant",
    "eureka/Enterprises",
    "eureka/Executive",
    "eureka/Fund",
    "eureka/Gold",
    "eureka/Meeting",
    "eureka/Mine",
    "eureka/Network",
    "eureka/Office",
    "eureka/Park",
    "eureka/Plaza",
    "eureka/Promenade",
    "eureka/Sales",
    "eureka/Suite",
    "eureka/Vault",
    "Heartland/Acres",
    "Heartland/Arbor",
    "Heartland/Bluffs",
    "Heartland/Brook",
    "Heartland/Cabin",
    "Heartland/Canyon",
    "Heartland/Cliffs",
    "Heartland/Cottage",
    "Heartland/Country",
    "Heartland/Creek",
    "Heartland/Estates",
    "Heartland/Falls",
    "Heartland/Farm",
    "Heartland/Fields",
    "Heartland/Flats",
    "Heartland/Forest",
    "Heartland/Garden",
    "Heartland/Glade",
    "Heartland/Grove",
    "Heartland/Hearth",
    "Heartland/Hills",
    "Heartland/Hollow",
    "Heartland/Lake",
    "Heartland/Lane",
    "Heartland/Meadows",
    "Heartland/Oaks",
    "Heartland/Orchard",
    "Heartland/Park",
    "Heartland/Pasture",
    "Heartland/Pines",
    "Heartland/Plains",
    "Heartland/Pointe",
    "Heartland/Pond",
    "Heartland/Prairie",
    "Heartland/Ranch",
    "Heartland/Ridge",
    "Heartland/River",
    "Heartland/Shores",
    "Heartland/Stream",
    "Heartland/Trail",
    "Heartland/Valley",
    "Heartland/Village",
    "Heartland/Vista",
    "Heartland/Woods",
    "Hollywood/Academy",
    "Hollywood/Agency",
    "Hollywood/Backdrop",
    "Hollywood/Boulevard",
    "Hollywood/Bungalow",
    "Hollywood/Camera",
    "Hollywood/Chateau",
    "Hollywood/Cinema",
    "Hollywood/Club",
    "Hollywood/Derby",
    "Hollywood/Diva",
    "Hollywood/Film",
    "Hollywood/Guild",
    "Hollywood/Heights",
    "Hollywood/Highrise",
    "Hollywood/Hills",
    "Hollywood/Interview",
    "Hollywood/Land",
    "Hollywood/Location",
    "Hollywood/Lot",
    "Hollywood/Makeup",
    "Hollywood/Mansion",
    "Hollywood/Movie",
    "Hollywood/Palace",
    "Hollywood/Park",
    "Hollywood/Pavillion",
    "Hollywood/Picture",
    "Hollywood/Prop",
    "Hollywood/Screen",
    "Hollywood/Set",
    "Hollywood/Star",
    "Hollywood/Studio",
    "Hollywood/Theater",
    "Hollywood/Trailer",
    "Hollywood/Video",
    "Hotsprings/Bath",
    "Hotsprings/Chalet",
    "Hotsprings/Falls",
    "Hotsprings/Oasis",
    "Hotsprings/Resort",
    "Hotsprings/Retreat",
    "Hotsprings/Sauna",
    "Hotsprings/Spa",
    "Hotsprings/Villa",
    "Madisonavenue/Boardroom",
    "Madisonavenue/Lobby",
    "Madisonavenue/Newsstand",
    "Motorcity/Boulevard",
    "Motorcity/Downs",
    "Motorcity/Factory",
    "Motorcity/Flats",
    "Motorcity/Freeway",
    "Motorcity/Garage",
    "Motorcity/Highway",
    "Motorcity/Lane",
    "Motorcity/Lot",
    "Motorcity/Pit",
    "Motorcity/Shop",
    "Motorcity/Show",
    "Motorcity/Speedway",
    "Motorcity/Street",
    "Motorcity/Strip",
    "Motorcity/Track",
    "Napavalley/Cellar",
    "Napavalley/Vineyard",
    "Nashville/Bluegrass",
    "Nashville/Opry",
    "Nashville/Ranch",
    "Nashville/Rodeo",
    "Nashville/Stage",
    "paris/Arc",
    "paris/Bistro",
    "paris/Boutique",
    "paris/Cabaret",
    "paris/Cafe",
    "paris/Cathedral",
    "paris/Chalet",
    "paris/Chateau",
    "paris/Cinema",
    "paris/Concorde",
    "paris/Gallery",
    "paris/Jardin",
    "paris/Leftbank",
    "paris/LeftBank",
    "paris/Library",
    "paris/Lights",
    "paris/Louvre",
    "paris/Maison",
    "paris/Metro",
    "paris/Musee",
    "paris/Opera",
    "paris/Palais",
    "paris/Parc",
    "paris/Pavilion",
    "paris/Promenade",
    "paris/Rue",
    "paris/Salon",
    "paris/Shoppe",
    "paris/Sorbonne",
    "paris/Theatre",
    "paris/Tower",
    "paris/Villa",
    "Pentagon/Barracks",
    "Pentagon/Base",
    "Pentagon/Bunker",
    "Pentagon/Camp",
    "Pentagon/Fort",
    "Pentagon/Quarters",
    "Petsburgh/Fair",
    "Petsburgh/Farm",
    "Petsburgh/Haven",
    "Petsburgh/Park",
    "Petsburgh/Reserve",
    "Petsburgh/Stable",
    "Petsburgh/Yard",
    "Petsburgh/Zoo",
    "Picketfence/Garden",
    "Picketfence/Street",
    "Pipeline/Cliff",
    "Pipeline/Curb",
    "Pipeline/Dropzone",
    "Pipeline/Halfpipe",
    "Pipeline/Ramp",
    "Pipeline/Ramp",
    "Pipeline/Rapids",
    "Pipeline/Reef",
    "Pipeline/Ridge",
    "Pipeline/Shore",
    "Pipeline/Slope",
    "Pipeline/Valley",
    "Rainforest/Andes",
    "Rainforest/Canopy",
    "Rainforest/Jungle",
    "Rainforest/Vines",
    "Rainforest/Watershed",
    "Rainforest/Wetlands",
    "Rodeodrive/Boutique",
    "Rodeodrive/Mall",
    "Researchtriangle/Campus",
    "Researchtriangle/Facility",
    "Researchtriangle/Forum",
    "Researchtriangle/Lab",
    "Researchtriangle/Node",
    "Researchtriangle/Station",
    "Researchtriangle/System",
    "Researchtriangle/Thinktank",
    "Siliconvalley/Bay",
    "Siliconvalley/Bit",
    "Siliconvalley/Board",
    "Siliconvalley/Bridge",
    "Siliconvalley/Byte",
    "Siliconvalley/Cable",
    "Siliconvalley/Campus",
    "Siliconvalley/Chip",
    "Siliconvalley/Circuit",
    "Siliconvalley/Code",
    "Siliconvalley/Drive",
    "Siliconvalley/File",
    "Siliconvalley/Foothills",
    "Siliconvalley/Garage",
    "Siliconvalley/Grid",
    "Siliconvalley/Hardware",
    "Siliconvalley/Haven",
    "Siliconvalley/Heights",
    "Siliconvalley/Hills",
    "Siliconvalley/Horizon",
    "Siliconvalley/Hub",
    "Siliconvalley/Lab",
    "Siliconvalley/Lakes",
    "Siliconvalley/Monitor",
    "Siliconvalley/Mouse",
    "Siliconvalley/Network",
    "Siliconvalley/Node",
    "Siliconvalley/Office",
    "Siliconvalley/Orchard",
    "Siliconvalley/Park",
    "Siliconvalley/Peaks",
    "Siliconvalley/Pines",
    "Siliconvalley/Platform",
    "Siliconvalley/Port",
    "Siliconvalley/Program",
    "Siliconvalley/Ridge",
    "Siliconvalley/Screen",
    "Siliconvalley/Sector",
    "Siliconvalley/Server",
    "Siliconvalley/Software",
    "Siliconvalley/Station",
    "Siliconvalley/Storage",
    "Siliconvalley/Vista",
    "Siliconvalley/Way",
    "Soho/Atrium",
    "Soho/Bistro",
    "Soho/Cafe",
    "Soho/Canvas",
    "Soho/Coffeehouse",
    "Soho/Courtyard",
    "Soho/Den",
    "Soho/Easel",
    "Soho/Exhibit",
    "Soho/Fountain",
    "Soho/Gallery",
    "Soho/Hall",
    "Soho/Lofts",
    "Soho/Museum",
    "Soho/Nook",
    "Soho/Opening",
    "Soho/Palette",
    "Soho/Park",
    "Soho/Rooftop",
    "Soho/Square",
    "Soho/Studios",
    "Soho/Study",
    "Soho/Suite",
    "Soho/Veranda",
    "Soho/Village",
    "Soho/Workshop",
    "Southbeach/Balcony",
    "Southbeach/Bay",
    "Southbeach/Bluffs",
    "Southbeach/Boardwalk",
    "Southbeach/Breakers",
    "Southbeach/Bungalow",
    "Southbeach/Cabana",
    "Southbeach/Canal",
    "Southbeach/Cape",
    "Southbeach/Castle",
    "Southbeach/Channel",
    "Southbeach/Cliffs",
    "Southbeach/Club",
    "Southbeach/Coast",
    "Southbeach/Cove",
    "Southbeach/Disco",
    "Southbeach/Docks",
    "Southbeach/Dunes",
    "Southbeach/Gulf",
    "Southbeach/Harbor",
    "Southbeach/Inlet",
    "Southbeach/Island",
    "Southbeach/Jetty",
    "Southbeach/Keys",
    "Southbeach/Lagoon",
    "Southbeach/Lights",
    "Southbeach/Lounge",
    "Southbeach/Mansion",
    "Southbeach/Marina",
    "Southbeach/Palace",
    "Southbeach/Palms",
    "Southbeach/Park",
    "Southbeach/Patio",
    "Southbeach/Pier",
    "Southbeach/Plateau",
    "Southbeach/Plaza",
    "Southbeach/Pointe",
    "Southbeach/Port",
    "Southbeach/Reef",
    "Southbeach/Sandbar",
    "Southbeach/Sands",
    "Southbeach/Seaside",
    "Southbeach/Shores",
    "Southbeach/Strand",
    "Southbeach/Suite",
    "Southbeach/Surf",
    "Southbeach/Terrace",
    "Southbeach/Tidepool",
    "Sunsetstrip/Alley",
    "Sunsetstrip/Amphitheatre",
    "Sunsetstrip/Arena",
    "Sunsetstrip/Auditorium",
    "Sunsetstrip/Backstage",
    "Sunsetstrip/Balcony",
    "Sunsetstrip/Bar",
    "Sunsetstrip/Basement",
    "Sunsetstrip/Bass",
    "Sunsetstrip/Beat",
    "Sunsetstrip/Birdland",
    "Sunsetstrip/Bistro",
    "Sunsetstrip/Booth",
    "Sunsetstrip/Cabaret",
    "Sunsetstrip/Club",
    "Sunsetstrip/Concert",
    "Sunsetstrip/Derby",
    "Sunsetstrip/Diner",
    "Sunsetstrip/Disco",
    "Sunsetstrip/Event",
    "Sunsetstrip/Exhibit",
    "Sunsetstrip/Festival",
    "Sunsetstrip/Floor",
    "Sunsetstrip/Frontrow",
    "Sunsetstrip/Gala",
    "Sunsetstrip/Garage",
    "Sunsetstrip/Hall",
    "Sunsetstrip/Hotel",
    "Sunsetstrip/Limo",
    "Sunsetstrip/Lobby",
    "Sunsetstrip/Loft",
    "Sunsetstrip/Loge",
    "Sunsetstrip/Lounge",
    "Sunsetstrip/Mezzanine",
    "Sunsetstrip/Palace",
    "Sunsetstrip/Palladium",
    "Sunsetstrip/Palms",
    "Sunsetstrip/Pavilion",
    "Sunsetstrip/Performance",
    "Sunsetstrip/Pit",
    "Sunsetstrip/Plaza",
    "Sunsetstrip/Scene",
    "Sunsetstrip/Set",
    "Sunsetstrip/Show",
    "Sunsetstrip/Stadium",
    "Sunsetstrip/Stage",
    "Sunsetstrip/Street",
    "Sunsetstrip/Studio",
    "Sunsetstrip/Tempo",
    "Sunsetstrip/Theater",
    "Sunsetstrip/Towers",
    "Sunsetstrip/Underground",
    "Sunsetstrip/Venue",
    "Sunsetstrip/Villa",
    "Sunsetstrip/Vine",
    "Thetropics/Bay",
    "Thetropics/Beach",
    "Thetropics/Breakers",
    "Thetropics/Cabana",
    "Thetropics/Coast",
    "Thetropics/Cove",
    "Thetropics/Equator",
    "Thetropics/Harbor",
    "Thetropics/Island",
    "Thetropics/Lagoon",
    "Thetropics/Mainland",
    "Thetropics/Palms",
    "Thetropics/Paradise",
    "Thetropics/Reef",
    "Thetropics/Resort",
    "Thetropics/Shores",
    "Televisioncity/Broadcast",
    "Televisioncity/Cable",
    "Televisioncity/Lot",
    "Televisioncity/Network",
    "Televisioncity/Satellite",
    "Televisioncity/Screen",
    "Televisioncity/Set",
    "Televisioncity/Stage",
    "Televisioncity/Station",
    "Televisioncity/Studio",
    "Televisioncity/Taping",
    "Televisioncity/Timessquare",
    "Tokyo/Adventure",
    "Tokyo/Alley",
    "Tokyo/Arcade",
    "Tokyo/Arena",
    "Tokyo/Avatar",
    "Tokyo/Battlefield",
    "Tokyo/Bridge",
    "Tokyo/Bunker",
    "Tokyo/Castle",
    "Tokyo/Cauldron",
    "Tokyo/Cave",
    "Tokyo/Cavern",
    "Tokyo/Chamber",
    "Tokyo/Chaos",
    "Tokyo/Chasm",
    "Tokyo/Corner",
    "Tokyo/Corridor",
    "Tokyo/Dome",
    "Tokyo/Dragon",
    "Tokyo/Dream",
    "Tokyo/Dungeon",
    "Tokyo/Fortress",
    "Tokyo/Frontier",
    "Tokyo/Galaxy",
    "Tokyo/Hangar",
    "Tokyo/Hero",
    "Tokyo/Labyrinth",
    "Tokyo/Lair",
    "Tokyo/Legend",
    "Tokyo/Maze",
    "Tokyo/Metro",
    "Tokyo/Portal",
    "Tokyo/Realm",
    "Tokyo/Ring",
    "Tokyo/Sewer",
    "Tokyo/Stadium",
    "Tokyo/Tower",
    "Tokyo/Zone",
    "Tokyo/Bay",
    "Tokyo/Blossom",
    "Tokyo/Bridge",
    "Tokyo/Club",
    "Tokyo/Courtyard",
    "Tokyo/Dojo",
    "Tokyo/Field",
    "Tokyo/Flats",
    "Tokyo/Fountain",
    "Tokyo/Fuji",
    "Tokyo/Garden",
    "Tokyo/Ginza",
    "Tokyo/Gulf",
    "Tokyo/Harbor",
    "Tokyo/Highrise",
    "Tokyo/Island",
    "Tokyo/Lights",
    "Tokyo/Market",
    "Tokyo/Pagoda",
    "Tokyo/Palace",
    "Tokyo/Ring",
    "Tokyo/Shores",
    "Tokyo/Shrine",
    "Tokyo/Spa",
    "Tokyo/Springs",
    "Tokyo/Subway",
    "Tokyo/Teahouse",
    "Tokyo/Temple",
    "Tokyo/Towers",
    "Tokyo/Villa",
    "Vienna/Alps",
    "Vienna/Choir",
    "Vienna/Opera",
    "Vienna/Recital",
    "Vienna/Stage",
    "Vienna/Strasse",
    "Vienna/Studio",
    "Vienna/Theatre",
    "Vienna/Waltz",
    "Wallstreet/Account",
    "Wallstreet/Bank",
    "Wallstreet/Bond",
    "Wallstreet/Brokerage",
    "Wallstreet/Bureau",
    "Wallstreet/District",
    "Wallstreet/Exchange",
    "Wallstreet/Floor",
    "Wallstreet/Fund",
    "Wallstreet/Highrise",
    "Wallstreet/Market",
    "Wallstreet/Stock",
    "Wellesley/Atrium",
    "Wellesley/Commons",
    "Wellesley/Garden",
    "Wellesley/Gazebo",
    "Wellesley/Park",
    "Wellesley/Parlor",
    "Wellesley/Veranda",
    "Westhollywood/Cafe",
    "Westhollywood/Castro",
    "Westhollywood/Chateau",
    "Westhollywood/Chelsea",
    "Westhollywood/Club",
    "Westhollywood/Heights",
    "Westhollywood/Parade",
    "Westhollywood/Park",
    "Westhollywood/Salon",
    "Westhollywood/Stonewall",
    "Westhollywood/Villa",
    "Westhollywood/Village",
    "Yosemite/Bench",
    "Yosemite/Bluegrass",
    "Yosemite/Cabin",
    "Yosemite/Campground",
    "Yosemite/Canyon",
    "Yosemite/Falls",
    "Yosemite/Forest",
    "Yosemite/Geyser",
    "Yosemite/Gorge",
    "Yosemite/Meadows",
    "Yosemite/Point",
    "Yosemite/Rapids",
    "Yosemite/Trails",
    "Fashionavenue/Agency",
    "Fashionavenue/Catwalk",
    "Fashionavenue/Mall",
    "Fashionavenue/Runway",
    "Fashionavenue/Salon",
    "Fashionavenue/Show",
    "Fashionavenue/Stage",
]


class GeocitiesArchiveCrawlerBot(Bot):
    def random_subneighborhood(self) -> str:
        """Generate a random geocities subneighborhood URL."""
        return BASE_URL + random.choice(SUB_NEIGHBORHOODS) + "/"

    def crawl_random_neighborhood(self) -> List[str]:
        """
        crawl all the links under a subneighborhood.
        """
        url = self.random_subneighborhood()
        while True:
            log.info(NAME + " - crawling " + url)
            r = requests.get(url)

            # check for 404
            site_text = r.text.strip().lower()
            if (
                r.status_code == 404
                or "http error 404" in site_text
                or "the page you requested was not found" in site_text
            ):
                log.warning(NAME + " could not find: " + url)
                url = self.random_subneighborhood()
                continue
            break
        log.info("successfully found a page!")
        soup = BeautifulSoup(r.content, "html.parser")
        return (
            url,
            [
                a.attrs["href"]
                for a in soup.find_all("a")
                if (
                    not a.attrs["href"].startswith("?")
                    and not a.attrs["href"].startswith("/")
                )
            ],
        )

    def generate(self, message, width, height, crop_top, **kwargs) -> PostContent:
        """generate a PostContent object from screenshot of random page."""
        base_url, page_urls = self.crawl_random_neighborhood()
        page = base_url + random.choice(page_urls)
        text = (
            message
            + page
            + """
        .
        .
        .
        .
        #bot #byb #geocitiesarchive #screenshots
        """
        )
        log.info(f"Screenshotting: {page}")
        tmpf = browser.screenshot(page, width, height)
        tmpf_jpg = tmpf.replace(".png", ".jpg")
        image.convert(tmpf, tmpf_jpg)
        bbox = image.getbbox(tmpf_jpg)
        media = image.crop(tmpf_jpg, (0, crop_top, bbox[2], bbox[3]), cleanup=True)
        return PostContent(media, text, urls=[page])


@click.command()
@click.option(
    "--message",
    default=DEFAULT_MESSAGE,
    help="A message to prefix the screenshot link, eg: " + DEFAULT_MESSAGE,
)
@click.option("--width", default=1000, help="The width of the browser")
@click.option("--height", default=768, help="The height of the browser")
@click.option("--crop_top", default=75, help="The offset to take the crop from")
@platform_opt
def cli(**kwargs):
    """
    Take a screenshot of a random page from geocities archive.
    """
    GeocitiesArchiveCrawlerBot().post_content_to_platforms(**kwargs)
